"""Custom configuration file definitions.

Add custom ConfigFile subclasses here to manage project-specific configuration files.
ConfigFile subclasses are automatically discovered and initialized when running
`pyrig mkroot`.
"""
